pub struct ScopedChartResources {
pub slide: HashMap<String, ChartResource>,
pub layout: HashMap<String, ChartResource>,
pub master: HashMap<String, ChartResource>,
}Expand description
Parsed chart resources kept separate by their producing part’s scope.
Fields
slide: HashMap<String, ChartResource>layout: HashMap<String, ChartResource>master: HashMap<String, ChartResource>Implementations
Sourceimpl ScopedChartResources
impl ScopedChartResources
Sourcepub fn get(
&self,
source: FlattenedSource,
relationship_id: &str,
) -> Option<&ChartResource>
pub fn get( &self, source: FlattenedSource, relationship_id: &str, ) -> Option<&ChartResource>
Look up a chart relationship only in its producing part’s scope.